@@ -9,10 +9,10 @@ import (
 	"testing"
 
 	sanitize "github.com/kennygrant/sanitize"
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	agentv1 "github.com/open-cluster-management/klusterlet-addon-controller/pkg/apis/agent/v1"
-	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/cluster/v1beta1"
+	agentv1 "github.com/stolostron/klusterlet-addon-controller/pkg/apis/agent/v1"
+	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
 	"github.com/stretchr/testify/assert"
+	clusterv1 "open-cluster-management.io/api/cluster/v1"
 )
 
 func unmarshalFile(filepath string, resourceType interface{}, t *testing.T) {
