@@ -7,6 +7,7 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package dbconnector
 
@@ -91,7 +92,7 @@ func encodeProperty(key string, value interface{}) (map[string]interface{}, erro
 		res[key] = tmpInterface
 
 	case map[string]interface{}:
-		if key == "label" {
+		if key == "label" || key == "addon" {
 			labelStrings := make([]string, 0, len(typedVal))
 			for key, value := range typedVal {
 				labelString := fmt.Sprintf("'%v=%v'", sanitizeValue(key), sanitizeValue(fmt.Sprintf("%v", value)))
